@@ -62,14 +62,16 @@ class AptCygInstaller(PackageManagerInstaller):
 
     def __init__(self):
         super(AptCygInstaller, self).__init__(cygcheck_detect)
+        self.as_root = False
+        self.sudo_command = 'cygstart --action=runas'
 
-    def get_install_command(self, resolved, interactive=True, reinstall=False):
+    def get_install_command(self, resolved, interactive=True, reinstall=False, quiet=False):
         packages = self.get_packages_to_install(resolved, reinstall=reinstall)        
         #TODO: interactive
         if not packages:
             return []
         else:
-            return [['apt-cyg', '-m', 'ftp://sourceware.org/pub/cygwinports', 'install']+packages]
+            return [self.elevate_priv(['apt-cyg', '-m', 'ftp://sourceware.org/pub/cygwinports', 'install'])+packages]
 
 if __name__ == '__main__':
     print("test cygcheck_detect(true)", cygcheck_detect('cygwin'))
