@@ -78,10 +78,10 @@ class PkgAddInstaller(Installer):
     def __init__(self):
         super(PkgAddInstaller, self).__init__(pkg_info_detect)
 
-    def get_install_command(self, resolved, interactive=True, reinstall=False):
+    def get_install_command(self, resolved, interactive=True, reinstall=False, quiet=False):
         packages = self.get_packages_to_install(resolved, reinstall=reinstall)        
         if not packages:
             return []
         else:
             #pkg_add does not have a non-interactive command
-            return [['sudo', '/usr/sbin/pkg_add', '-r']+packages]
+            return [self.elevate_priv(['/usr/sbin/pkg_add', '-r'])+packages]
